@@ -21,17 +21,18 @@
 #ifndef KPARTLOADER_H
 #define KPARTLOADER_H
 
-#include <kparts/mainwindow.h>
-#include <kparts/readonlypart.h>
+// KF
+#include <KParts/MainWindow>
+#include <KParts/ReadOnlyPart>
 
 class KPartLoaderWindow : public KParts::MainWindow
 {
   Q_OBJECT
 public:
   KPartLoaderWindow(const QString& partLib);
-  virtual ~KPartLoaderWindow();
+  ~KPartLoaderWindow() override;
 
-private slots:
+private Q_SLOTS:
   void aboutKPart();
 
 private:
